@@ -98,12 +98,13 @@ class PatchReviewBehaviour(EntityAdapter):
             'Any U, MAX(D) GROUPBY U '
             'WHERE P eid %(p)s, '
             '      P patch_revision RE, '
+            '      RE from_repository R, '
             '      NOT P created_by U, '
+            '      U in_state S, NOT S name "deactivated", '
             '      X? patch_reviewer U, '
             '      X creation_date D, '
             '      EXISTS(R use_global_groups TRUE, U in_group G, G name "reviewers") '
-            '      OR EXISTS(RE from_repository R, '
-            '                R repository_reviewer U)',
+            '      OR EXISTS(R repository_reviewer U)',
             {'p': self.entity.eid})
 
     def set_reviewers(self):
