@@ -49,6 +49,14 @@ class AutomaticWebTest(testlib.AutomaticWebTest):
                              'depends_on',
                              'point_of'))
 
+    def to_test_etypes(self):
+        return set(('Repository',
+                    'Revision',
+                    'Patch',
+                    'InsertionPoint',
+                    ))
+
+
     @classmethod
     def setUpClass(cls):
         cls.__tmpdir = tempfile.mkdtemp(prefix='vcreview-test-')
