@@ -138,13 +138,17 @@ class PatchReviewWorkflowTC(CubicWebTC):
         2) Test that `reviewer` group can be disabled on a repo.
         """
         req = self.request()
+        otherrepo = req.create_entity('Repository', type=u'mercurial',
+                                      encoding=u'utf8',
+                                      path=u'/dev/null',
+                                      has_review=True)
         req.execute('SET X repository_reviewer U WHERE U login "committer"')
         patch = req.entity_from_eid(self.patch1eid)
         ireview = patch.cw_adapt_to('IPatchReviewControl')
         self.assertEqual(set(x for x,_ in ireview.reviewers_rset().rows),
                          set([self.reviewer2.eid,
                               self.committer.eid]))
-        req.execute('SET X use_global_groups FALSE')
+        req.execute('SET X use_global_groups FALSE WHERE NOT X eid %(e)s', {'e': otherrepo.eid})
         patch.cw_clear_all_caches()
         ireview = patch.cw_adapt_to('IPatchReviewControl')
         self.assertEqual(set(x for x,_ in ireview.reviewers_rset().rows),
