@@ -19,6 +19,7 @@ __docformat__ = "restructuredtext en"
 _ = unicode
 
 from logilab.common.decorators import cached
+from logilab.mtconverter import xml_escape
 
 from cubicweb import tags, view
 from cubicweb.selectors import is_instance, rql_condition, anonymous_user
@@ -32,11 +33,10 @@ class AllActivePatches(view.StartupView):
     __regid__ = 'vcreview.allactivepatches'
     title = _('All active patches')
 
-    rql = ('Any P,GROUP_CONCAT(PO),P,P,PB,PS,R '
+    rql = ('Any P,P,P,P,PB,PS,R '
            'GROUPBY R,P,PB,PS '
            'ORDERBY RT,PB '
            'WHERE P patch_revision RE, '
-           '      RE author PO, '
            '      RE branch PB, '
            '      P in_state PS,'
            '      RE from_repository R, '
@@ -58,13 +58,12 @@ class UserWorkList(AllActivePatches):
     __regid__ = 'vcreview.patches.worklist'
     title = _('My review worklist')
 
-    rql = ('Any P,GROUP_CONCAT(PO),P,P,PB,PS,R '
+    rql = ('Any P,P,P,P,PB,PS,R '
            'GROUPBY R,P,PB,PS '
            'ORDERBY RT,PB '
            'WHERE U eid %(u)s, '
            '      P in_state PS, '
            '      P patch_revision RE, '
-           '      RE author PO, '
            '      RE branch PB, '
            '      RE from_repository R, '
            '      R title RT, '
@@ -90,7 +89,7 @@ class PatchesTable(tableview.TableView):
 
     def call(self, **kwargs):
         kwargs['paginate'] = True
-        super(PatchesTable, self).call(cellvids={2: 'vcreview.patch.reviewers', 3: 'vcreview.patch.committers'},
+        super(PatchesTable, self).call(cellvids={1: 'vcreview.patch.authors', 2: 'vcreview.patch.reviewers', 3: 'vcreview.patch.committers'},
                                        **kwargs)
 
     def column_label(self, colidx, default, translate_func=None):
@@ -103,6 +102,12 @@ class PatchesTable(tableview.TableView):
         return super(PatchesTable, self).column_label(colidx, default, translate_func)
 
 
+class PatchAuthors(view.EntityView):
+    __regid__ = 'vcreview.patch.authors'
+    __select__ = is_instance('Patch')
+    def entity_call(self, entity, **kwargs):
+        self.w(u', '.join(set(xml_escape(rev.author) for rev in entity.patch_revision)))
+
 class PatchReviewer(view.EntityView):
     __regid__ = 'vcreview.patch.reviewers'
     __select__ = is_instance('Patch')
